@@ -19,14 +19,13 @@ $VERSION = 0.01;
     'find' => '/sw/bin/find',
     'g++' => '/usr/bin/g++',
     'grep' => '/usr/bin/grep',
-    'ld' => '/usr/bin/g++',
     'ln' => '/sw/bin/ln',
     'make' => '/sw/bin/make',
     'mkdir' => '/sw/bin/mkdir',
     'mv' => '/sw/bin/mv',
     'perl' => '/usr/bin/perl',
     'rm' => '/bin/rm',
-    'rsync' => '/usr/local/bin/rsync',
+    'rsync' => '/usr/bin/rsync',
     'ssh' => '/sw/bin/ssh',
     'yapp' => '/usr/bin/yapp',
   },
